# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.3.1~ece0510',
    built_at='2024-02-21 21:06:08Z',
    sha='ece0510afe541ef86b42a5e4fb57ea5c0dfbda3c',
    branch='HEAD',
    tag='v4.3.1',
)
